@@ -211,4 +211,7 @@ class FeatureGroupVersion(AbstractApiClass):
                 reader = fastavro.reader(data)
                 data_df = data_df.append(
                     pd.DataFrame.from_records([r for r in reader]))
+                for col in data_df.columns:
+                    if pd.core.dtypes.common.is_datetime64_ns_dtype(data_df[col]):
+                        data_df[col] = data_df[col].dt.tz_localize(None)
         return data_df
